# System configuration

Debug

1. {{item.name}}
   1. {{subItem.name}}

Configuring: {{$ctrl.model.componentclass}}:{{$ctrl.model.name}}
Select a component to configure in the pane to the left.
Stored Modified

Model:

    {{$ctrl.model | json}}

Schema:

    {{$ctrl.schema | json}}

Form:

    {{$ctrl.form | json}}

Schemata:

    {{$ctrl.configschemata}}

All Schemata:

    {{$ctrl.configschemadata | json}}